/*****************************************************************************
 * ethernet.c
 * 
 * Dmonstration Ethernet AVRlib
 * 
 * 
 * Auteur : Eric PASCUAL pour POBOT
 * Cible : ATmega
 * Compilateur : avr-gcc (WinAVR)
 */

#include <avr/pgmspace.h>
#include <avr/io.h>				// dfinitions des I/O
#include <avr/interrupt.h>		// support des interruptions 
#include <stdlib.h>
#include <string.h>

#include "global.h"
#include "a2d.h"
#include "glcd.h"
#include "ks0108.h"
#include "timer.h"

//-----------------------------------------------------------------
char *msg1="Board to pos    ";
char *msg2="and press RB0   ";
char *msg3="Zero G values : ";
char *msg4="X=      Y=      ";
char *msg5="One G values :  ";
char *msg6="Readings :      ";


static void display_uint_at(unsigned short value, u08 line, u08 col) {
	static char buffer[8] ;

	itoa(value, buffer, 10) ;
	buffer[7] = 0 ;
	glcdGotoChar(line, col) ;
	glcdPutStr (buffer) ;
} 

int main(void) {
	DDRB = 0xfe ;		// PB0 used as input
	
	a2dInit() ;
	glcdInit() ;
	timerInit() ;
	
	u08 position_num = 1 ;
	u08 line = 0 ;

	glcdClearScreen() ;
	glcdGotoChar(line, 0) ; 
	glcdPutStr(msg1) ;
	glcdWriteChar(position_num++ + 48) ;
	glcdGotoChar(++line, 0) ;
	glcdPutStr(msg2) ;
	while (!(PINB & 0x01)) ; while ((PINB & 0x01)) ;
	
	unsigned short zeroG_X = a2dConvert10bit(0) ;
	unsigned short zeroG_Y = a2dConvert10bit(1) ;

	glcdGotoChar(++line, 0) ; 
	glcdPutStr(msg1) ;
	glcdWriteChar(position_num++ + 48) ;
	glcdGotoChar(++line, 0) ;
	glcdPutStr(msg2) ;
	while (!(PINB & 0x01)) ; while ((PINB & 0x01)) ;

	unsigned short oneG_X = a2dConvert10bit(0) ;

	glcdGotoChar(++line, 0) ; 
	glcdPutStr(msg1) ;
	glcdWriteChar(position_num++ + 48) ;
	glcdGotoChar(++line, 0) ;
	glcdPutStr(msg2) ;
	while (!(PINB & 0x01)) ; while ((PINB & 0x01)) ;

	unsigned short oneG_Y = a2dConvert10bit(1) ;
	
	glcdClearScreen() ;
	line = 0 ;
	glcdGotoChar(line, 0) ; 
	glcdPutStr(msg3) ;
	glcdGotoChar(++line, 0) ; 
	glcdPutStr(msg4) ;
	display_uint_at (zeroG_X, line, 2) ;
	display_uint_at (zeroG_Y, line, 10) ;
	
	glcdGotoChar(++line, 0) ; 
	glcdPutStr(msg5) ;
	glcdGotoChar(++line, 0) ; 
	glcdPutStr(msg4) ;
	display_uint_at (oneG_X, line, 2) ;
	display_uint_at (oneG_Y, line, 10) ;
	
	line+=2 ;
	glcdGotoChar(line, 0) ; 
	glcdPutStr(msg6) ;
	glcdGotoChar(++line, 0) ; 
	glcdPutStr(msg4) ;

	while (1) {
		timerPause(100) ;
	
		oneG_X = a2dConvert10bit(0) ;
		oneG_Y = a2dConvert10bit(1) ;
		display_uint_at (oneG_X, line, 2) ;
		display_uint_at (oneG_Y, line, 10) ;
	} 
}

